@@ -2,14 +2,14 @@
 #######################################################################
 """FriendBlog class for the Zope 3 based ng.skin.greenpsy package
 
-$Id: friendblog.py 51736 2008-09-16 20:53:35Z cray $
+$Id: friendblog.py 52235 2008-12-27 22:59:22Z cray $
 """
 __author__  = "Andrey Orlov, 2008"
 __license__ = "GPL"
-__version__ = "$Revision: 51736 $"
+__version__ = "$Revision: 52235 $"
 
-from ng.site.content.profileadapter.profileadapter import profileadapter
-from ng.content.annotation.friendobjectqueueannotation.interfaces import IFriendObjectQueueAnnotation
+from ng.site.addon.profile.profileadapter.profileadapter import profileadapter
+from ng.content.profile.friendobjectqueueannotation.interfaces import IFriendObjectQueueAnnotation
 
 class FriendBlog(object) :
 
