@@ -2,7 +2,7 @@
 #######################################################################
 """Mixin class for specific register form
 
-$Id: register.py 51521 2008-08-25 08:08:01Z cray $
+$Id: register.py 52188 2008-12-25 20:27:05Z cray $
 """
 __author__  = "Andrey Orlov, 2008"
 __license__ = "GPL"
@@ -11,7 +11,7 @@ __version__ = "$Revision: 50628 $"
 from zope.app.zapi import getUtility
 from zope.schema import getFieldNames
 from ng.content.article.interfaces import IDocShort
-from ng.content.annotation.profileannotation.interfaces import IProfileAnnotation
+from ng.content.profile.profileannotation.interfaces import IProfileAnnotation
 from interfaces import IRegisterForm
 
 class Register(object) :
