@@ -2,23 +2,23 @@
 #######################################################################
 """The definitions of a few viewlet provider.
 
-$Id: interfaces.py 51517 2008-08-23 01:32:31Z cray $
+$Id: interfaces.py 52423 2009-01-31 16:34:40Z cray $
 """
 __author__  = "Andrey Orlov, 2008"
 __license__ = "GPL"
-__version__ = "$Revision: 51517 $"
+__version__ = "$Revision: 52423 $"
 
 from zope.viewlet import interfaces
 from ng.skin.base.viewlet.viewletmain.interfaces import ICommonNewsListBoxProvider
 from ng.skin.base.viewlet.viewletmain.interfaces import INewsListBoxProvider
 from ng.skin.base.viewlet.viewletmain.interfaces import ICurrentBoxProvider
-from ng.skin.greenpsy.viewletprofilemenu.interfaces import IProfileMenuBoxProvider
-from ng.skin.greenpsy.viewletlogin.interfaces import ILoginBoxProvider
+from ng.skin.base.viewlet.viewlettoolbox.interfaces import IToolBoxProvider
+from ng.skin.base.viewlet.viewletloginbox.interfaces import ILoginBoxProvider
 from ng.skin.greenpsy.viewletgoogleads.interfaces import IGoogleAdsBoxProvider
 
 class IRightColumn(
     #IGoogleAdsBoxProvider,
-    IProfileMenuBoxProvider, 
+    IToolBoxProvider, 
     ILoginBoxProvider,
     ICommonNewsListBoxProvider,
     INewsListBoxProvider, 
